@@ -1,5 +1,5 @@
 from ...utils import except_none_self
-from ..exceptions import KeyboardError
+from vkbottle.utils.exceptions import KeyboardError
 
 
 class Action:
@@ -18,7 +18,7 @@ class Action:
                     "Action {} cannot assign {}".format(cls.__class__.__name__, k)
                 )
             setattr(cls, k, v)
-            cls.type = getattr(cls, "type")
+        cls.type = getattr(cls, "type")
 
     def dict(self):
         return vars(self)
