@@ -1,8 +1,11 @@
+import enum
 import typing
 from abc import ABC, abstractmethod
+
+from vkbottle.framework.framework.branch.standard_branch import BranchCheckupKey
+from vkbottle.utils.util import ContextInstanceMixin
 from .cls import AbstractBranch
 from ..rule import AbstractMessageRule
-import enum
 
 Branch = typing.Union[str, AbstractBranch]
 BranchRule = typing.Tuple[typing.Callable, typing.List[AbstractMessageRule]]
@@ -14,11 +17,12 @@ class GeneratorType(enum.Enum):
     DICT = "dict"
 
 
-class AbstractBranchGenerator(ABC):
+class ABCBranchGenerator(ABC, ContextInstanceMixin):
     Disposal = typing.Dict[str, BranchRule]
     cls_branch: typing.Any
     simple_branch: typing.Any
     generator: GeneratorType = GeneratorType.ABSTRACT
+    checkup_key: BranchCheckupKey = BranchCheckupKey.PEER_ID
 
     @abstractmethod
     def from_function(self, *args, **kwargs) -> None:
@@ -35,7 +39,13 @@ class AbstractBranchGenerator(ABC):
 
     @property
     @abstractmethod
-    async def branches(self) -> typing.Dict[str, typing.Tuple[AbstractBranch, ...]]:
+    def branches(self) -> typing.Dict[str, typing.Tuple[AbstractBranch, ...]]:
+        ...
+
+    @abstractmethod
+    def add_branches(
+        self, new_branches: typing.Dict[str, typing.Tuple[AbstractBranch, ...]]
+    ):
         ...
 
     @abstractmethod
@@ -45,7 +55,7 @@ class AbstractBranchGenerator(ABC):
     @abstractmethod
     async def load(
         self, uid: int
-    ) -> typing.Tuple["AbstractBranchGenerator.Disposal", AbstractBranch]:
+    ) -> typing.Tuple["ABCBranchGenerator.Disposal", AbstractBranch]:
         ...
 
     @abstractmethod
