@@ -20,34 +20,36 @@ class AbstractBranch(Copy):
         self.context = context
         ...
 
-    async def enter(self, ans: Message):
+    async def enter(self):
         ...
 
     async def branch(self, ans: Message, *args):
         ...
 
-    async def exit(self, ans: Message):
+    async def exit(self):
         ...
 
     def __repr__(self):
         return f"<Branch {self.__class__.__name__}>"
 
 
-
 class ClsBranch(AbstractBranch):
-    async def enter(self, ans: Message):
+    async def enter(self):
         logger.info("Branch {} entered at", self.key)
 
-    async def exit(self, ans: Message):
+    async def exit(self):
         logger.info("Branch {} exit at", self.key)
 
 
 class CoroutineBranch(AbstractBranch):
-    async def enter(self, ans):
+    async def enter(self):
         logger.info("Branch {} entered at", self.key or self.data["call"].__name__)
 
-    async def exit(self, ans):
+    async def exit(self):
         logger.info("Branch {} exit at", self.key or self.data["call"].__name__)
 
     async def branch(self, ans, *args):
         return await self.data["call"](ans, *args, **self.context)
+
+    def __call__(self):
+        return self
