@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 from vkbottle.utils import ContextInstanceMixin
+from .storage import ABCStorage
 import typing
 
 
@@ -16,6 +17,11 @@ class AbstractExtension(ABC, ContextInstanceMixin):
     def random_id(self) -> int:
         pass
 
+    @property
+    @abstractmethod
+    def storage(self) -> ABCStorage:
+        pass
+
     @abstractmethod
     def api_instance(self):
         pass
