@@ -3,7 +3,7 @@ from ..rule import AbstractRule, RuleExecute
 
 
 class AbstractFilter:
-    def __init__(self, *rules: typing.Tuple[AbstractRule]):
+    def __init__(self, *rules: AbstractRule):
         self.rules: typing.Tuple[AbstractRule] = rules
         self.context = RuleExecute()
 
@@ -16,3 +16,10 @@ class AbstractFilter:
 
     async def check(self, event) -> bool:
         ...
+
+    def __repr__(self):
+        return (
+            f"<Filter {self.__class__.__qualname__} "
+            f"rules={(rule.__class__.__name__ for rule in self.rules)} "
+            f"context={self.context}>"
+        )
