@@ -8,11 +8,11 @@ class BaseModel(pydantic.BaseModel):
         use_enum_values = True
 
     def __str__(self):
-        return str(self.dict(skip_defaults=True))
+        return str(self.dict(exclude_unset=True))
 
     def __repr__(self):
         args = ", ".join(
-            [f"{key}={value}" for key, value in self.dict(skip_defaults=True).items()]
+            [f"{key}={value}" for key, value in self.dict(exclude_unset=True).items()]
         )
         return "{}({})".format(self.__class__.__name__, args)
 
