@@ -1,13 +1,6 @@
 import typing
 from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
-
-
-class AppLeaderboardType(Enum):
-    _0 = "0"
-    _1 = "1"
-    _2 = "2"
 
 
 class AppMin(BaseModel):
@@ -20,6 +13,12 @@ class AppMin(BaseModel):
     icon_278: str = None
     icon_75: str = None
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        return self.id == other.id
+
 
 class App(AppMin):
     author_group: int = None
@@ -33,7 +32,7 @@ class App(AppMin):
     genre_id: int = None
     international: int = None
     is_in_catalog: int = None
-    leaderboard_type: "AppLeaderboardType" = None
+    leaderboard_type: int = None
     members_count: int = None
     platform_id: int = None
     published_date: int = None
