@@ -1,15 +1,6 @@
 from . import base
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
-
-
-class DefaultOrder(Enum):
-    _1 = "1"
-    _2 = "2"
-    minus1 = "-1"
-    minus2 = "-2"
 
 
 class Topic(BaseModel):
@@ -23,6 +14,12 @@ class Topic(BaseModel):
     updated: int = None
     updated_by: int = None
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        return self.id == other.id
+
 
 class TopicComment(BaseModel):
     attachments: typing.List = None
