@@ -1,7 +1,5 @@
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Thread(BaseModel):
