@@ -1,8 +1,7 @@
-from . import base
+from . import base, photos
 import typing
 from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Doc(BaseModel):
@@ -18,6 +17,12 @@ class Doc(BaseModel):
     type: int = None
     url: str = None
 
+    def __hash__(self):
+        return hash((self.owner_id, self.id))
+
+    def __eq__(self, other):
+        return self.owner_id == other.owner_id and self.id == other.id
+
 
 class DocAttachmentType(Enum):
     doc = "doc"
@@ -31,7 +36,7 @@ class DocPreview(BaseModel):
 
 
 class DocPreviewPhoto(BaseModel):
-    sizes: typing.List = None
+    sizes: typing.List["photos.PhotoSizes"] = None
 
 
 class DocPreviewVideo(BaseModel):
