@@ -1,8 +1,6 @@
 from . import groups
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class EventAttach(BaseModel):
@@ -11,7 +9,7 @@ class EventAttach(BaseModel):
     friends: typing.List = None
     id: int = None
     is_favorite: bool = None
-    member_status: "groups.GroupFullMemberStatus" = None
+    member_status: int = None
     text: str = None
     time: int = None
 
