@@ -1,8 +1,7 @@
-from . import base, wall, market, video, groups, users, link
+from . import wall, market, video, groups, users, link
 import typing
 from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Bookmark(BaseModel):
@@ -43,6 +42,12 @@ class Tag(BaseModel):
     id: int = None
     name: str = None
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        return self.id == other.id
+
 
 Bookmark.update_forward_refs()
 Page.update_forward_refs()
