@@ -1,23 +1,20 @@
-from . import base, users
+from . import base
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class FriendStatus(BaseModel):
-    friend_status: "FriendStatusStatus" = None
+    friend_status: int = None
     read_state: "base.BoolInt" = None
     request_message: str = None
     sign: str = None
     user_id: int = None
 
+    def __hash__(self):
+        return hash(self.user_id)
 
-class FriendStatusStatus(Enum):
-    _0 = "0"
-    _1 = "1"
-    _2 = "2"
-    _3 = "3"
+    def __eq__(self, other):
+        return self.user_id == other.user_id
 
 
 class FriendsList(BaseModel):
@@ -30,12 +27,24 @@ class MutualFriend(BaseModel):
     common_friends: typing.List = None
     id: int = None
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        return self.id == other.id
+
 
 class Requests(BaseModel):
     _from: str = None
     mutual: "RequestsMutual" = None
     user_id: int = None
 
+    def __hash__(self):
+        return hash(self.user_id)
+
+    def __eq__(self, other):
+        return self.user_id == other.user_id
+
 
 class RequestsMutual(BaseModel):
     count: int = None
@@ -48,6 +57,12 @@ class RequestsXtrMessage(BaseModel):
     mutual: "RequestsMutual" = None
     user_id: int = None
 
+    def __hash__(self):
+        return hash(self.user_id)
+
+    def __eq__(self, other):
+        return self.user_id == other.user_id
+
 
 FriendStatus.update_forward_refs()
 FriendsList.update_forward_refs()
