@@ -1,7 +1,5 @@
-import typing
-from enum import Enum
+from enum import IntEnum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Gift(BaseModel):
@@ -13,11 +11,17 @@ class Gift(BaseModel):
     message: str = None
     privacy: "GiftPrivacy" = None
 
+    def __hash__(self):
+        return hash((self.from_id, self.id))
 
-class GiftPrivacy(Enum):
-    _0 = "0"
-    _1 = "1"
-    _2 = "2"
+    def __eq__(self, other):
+        return self.from_id == other.from_id and self.id == other.id
+
+
+class GiftPrivacy(IntEnum):
+    visible_name_and_message = 0
+    visible_name = 1
+    visible_only_owner = 2
 
 
 class Layout(BaseModel):
@@ -26,6 +30,12 @@ class Layout(BaseModel):
     thumb_48: str = None
     thumb_96: str = None
 
+    def __hash__(self):
+        return hash(self.id)
+
+    def __eq__(self, other):
+        return self.id == other.id
+
 
 Gift.update_forward_refs()
 Layout.update_forward_refs()
