@@ -1,7 +1,4 @@
-import typing
 from enum import Enum
-from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Type(Enum):
