@@ -1,8 +1,5 @@
 from . import base
-import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Note(BaseModel):
@@ -17,6 +14,12 @@ class Note(BaseModel):
     title: str = None
     view_url: str = None
 
+    def __hash__(self):
+        return hash((self.owner_id, self.id))
+
+    def __eq__(self, other):
+        return self.owner_id == other.owner_id and self.id == other.id
+
 
 class NoteComment(BaseModel):
     date: int = None
