@@ -1,8 +1,6 @@
 from . import base, wall, photos, board, video
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Feedback(BaseModel):
