@@ -1,14 +1,6 @@
 from . import base
-import typing
 from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
-
-
-class PrivacySettings(Enum):
-    _0 = "0"
-    _1 = "1"
-    _2 = "2"
 
 
 class Wikipage(BaseModel):
@@ -20,8 +12,14 @@ class Wikipage(BaseModel):
     id: int = None
     title: str = None
     views: int = None
-    who_can_edit: "PrivacySettings" = None
-    who_can_view: "PrivacySettings" = None
+    who_can_edit: int = None
+    who_can_view: int = None
+
+    def __hash__(self):
+        return hash((self.group_id, self.id))
+
+    def __eq__(self, other):
+        return self.group_id == other.group_id and self.id == other.id
 
 
 class WikipageFull(BaseModel):
@@ -38,8 +36,14 @@ class WikipageFull(BaseModel):
     title: str = None
     view_url: str = None
     views: int = None
-    who_can_edit: "PrivacySettings" = None
-    who_can_view: "PrivacySettings" = None
+    who_can_edit: int = None
+    who_can_view: int = None
+
+    def __hash__(self):
+        return hash((self.group_id, self.id))
+
+    def __eq__(self, other):
+        return self.group_id == other.group_id and self.id == other.id
 
 
 class WikipageHistory(BaseModel):
