@@ -1,7 +1,5 @@
 import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Answer(BaseModel):
@@ -14,13 +12,19 @@ class Answer(BaseModel):
 class Poll(BaseModel):
     anonymous: bool = None
     answer_id: int = None
-    answers: typing.List = None
+    answers: typing.List[Answer] = None
     created: int = None
     id: int = None
     owner_id: int = None
     question: str = None
     votes: str = None
 
+    def __hash__(self):
+        return hash((self.owner_id, self.id))
+
+    def __eq__(self, other):
+        return self.owner_id == other.owner_id and self.id == other.id
+
 
 class Voters(BaseModel):
     answer_id: int = None
