@@ -1,8 +1,5 @@
 from . import audio
-import typing
-from enum import Enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class Status(BaseModel):
