@@ -1,5 +1,4 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
@@ -24,7 +23,7 @@ class ChangePasswordModel(BaseModel):
 
 class GetActiveOffers(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[int] = None
 
 
 class GetActiveOffersModel(BaseModel):
@@ -40,9 +39,7 @@ class GetAppPermissionsModel(BaseModel):
 
 class GetBanned(BaseModel):
     count: int = None
-    items: typing.List = None
-    profiles: typing.List = None
-    groups: typing.List = None
+    items: typing.List[objects.users.User] = None
 
 
 class GetBannedModel(BaseModel):
@@ -75,12 +72,3 @@ GetPushSettings = objects.account.PushSettings
 
 class GetPushSettingsModel(BaseModel):
     response: GetPushSettings = None
-
-
-class SaveProfileInfo(BaseModel):
-    changed: objects.base.BoolInt = None
-    name_request: objects.account.NameRequest = None
-
-
-class SaveProfileInfoModel(BaseModel):
-    response: SaveProfileInfo = None
