@@ -1,5 +1,4 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
@@ -12,7 +11,7 @@ class SendRequestModel(BaseModel):
 
 class GetCatalog(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.apps.App] = None
 
 
 class GetCatalogModel(BaseModel):
@@ -21,7 +20,7 @@ class GetCatalogModel(BaseModel):
 
 class GetFriendsList(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.users.User] = None
 
 
 class GetFriendsListModel(BaseModel):
@@ -30,16 +29,21 @@ class GetFriendsListModel(BaseModel):
 
 class GetLeaderboard(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.users.User] = None
 
 
 class GetLeaderboardModel(BaseModel):
     response: GetLeaderboard = None
 
 
+class Scope(BaseModel):
+    name: str = None
+    title: str = None
+
+
 class GetScopes(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[Scope] = None
 
 
 class GetScopesModel(BaseModel):
@@ -55,7 +59,7 @@ class GetScoreModel(BaseModel):
 
 class Get(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.apps.App] = None
 
 
 class GetModel(BaseModel):
