@@ -1,13 +1,11 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
 
 class GetTopics(BaseModel):
     count: int = None
-    items: typing.List = None
-    default_order: objects.board.DefaultOrder = None
+    items: typing.List[objects.board.Topic] = None
     can_add_topics: objects.base.BoolInt = None
 
 
@@ -31,7 +29,7 @@ class CreateCommentModel(BaseModel):
 
 class GetComments(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.board.TopicComment] = None
     poll: objects.board.TopicPoll = None
 
 
