@@ -1,5 +1,4 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
@@ -31,7 +30,7 @@ class DeleteModel(BaseModel):
 
 class GetList(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[int] = None
 
 
 class GetListModel(BaseModel):
