@@ -1,5 +1,4 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
@@ -45,9 +44,7 @@ class GetUserSubscriptionByIdModel(BaseModel):
     response: GetUserSubscriptionById = None
 
 
-class GetUserSubscriptions(BaseModel):
-    count: int = None
-    items: typing.List = None
+GetUserSubscriptions = objects.orders.Subscription
 
 
 class GetUserSubscriptionsModel(BaseModel):
