@@ -1,12 +1,11 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
 
 class Get(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.pretty_cards.PrettyCard] = None
 
 
 class GetModel(BaseModel):
