@@ -1,7 +1,5 @@
 import typing
-import enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 Get = typing.Dict
 
