@@ -1,7 +1,4 @@
-import typing
-import enum
 from ..base import BaseModel
-from vkbottle.types import objects
 
 
 class GetServerUrl(BaseModel):
