@@ -1,5 +1,4 @@
 import typing
-import enum
 from ..base import BaseModel
 from vkbottle.types import objects
 
@@ -19,7 +18,7 @@ class CheckLinkModel(BaseModel):
 
 class GetLastShortenedLinks(BaseModel):
     count: int = None
-    items: typing.List = None
+    items: typing.List[objects.utils.LastShortenedLink] = None
 
 
 class GetLastShortenedLinksModel(BaseModel):
